pub struct CreateDatabaseHostOptions {
pub name: CompactString,
pub type: DatabaseType,
pub deployment_enabled: bool,
pub maintenance_enabled: bool,
pub public_host: Option<CompactString>,
pub host: CompactString,
pub public_port: Option<u16>,
pub port: u16,
pub username: CompactString,
pub password: CompactString,
}Fields
name: CompactStringtype: DatabaseTypedeployment_enabled: boolmaintenance_enabled: boolpublic_host: Option<CompactString>host: CompactStringpublic_port: Option<u16>port: u16username: CompactStringpassword: CompactStringTrait Implementations
Sourceimpl ComposeSchema for CreateDatabaseHostOptions
impl ComposeSchema for CreateDatabaseHostOptions
Sourceimpl<'de> Deserialize<'de> for CreateDatabaseHostOptions
impl<'de> Deserialize<'de> for CreateDatabaseHostOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateDatabaseHostOptions
impl ToSchema for CreateDatabaseHostOptions
Sourceimpl Validate for CreateDatabaseHostOptions
impl Validate for CreateDatabaseHostOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateDatabaseHostOptions
impl RefUnwindSafe for CreateDatabaseHostOptions
impl Send for CreateDatabaseHostOptions
impl Sync for CreateDatabaseHostOptions
impl Unpin for CreateDatabaseHostOptions
impl UnwindSafe for CreateDatabaseHostOptions